@@ -79,7 +79,7 @@ int plugin_api_version = PLUGIN_API_VERSION;
 
 gmpcPlugin plugin = {
 	"Magnatune Stream Browser",
-	{0,1,0},
+	{0,15,0},
 	GMPC_PLUGIN_PL_BROWSER|GMPC_PLUGIN_META_DATA,
 	0,/* id */
 	NULL,/* path */
@@ -126,7 +126,7 @@ static void magnatune_logo_add()
 
 	ali = gtk_alignment_new(0,0.5,0,1);
 	gtk_container_add(GTK_CONTAINER(ali), button);
-	logo = gtk_image_new_from_stock("gmpc-magnatune", GTK_ICON_SIZE_DND);
+	logo = gtk_image_new_from_icon_name("magnatune", GTK_ICON_SIZE_DND);
 //	gtk_box_pack_start(GTK_BOX(magnatune_logo), logo, FALSE, FALSE,0);
 	gtk_button_set_image(GTK_BUTTON(button), logo);
 	gtk_box_pack_start(GTK_BOX(magnatune_logo), ali, TRUE, TRUE,0);
@@ -146,18 +146,11 @@ static void magnatune_logo_add()
 static void magnatune_logo_init()
 {
 	gchar *path = NULL;
-	GtkIconSet *set;
-	GtkIconFactory *factory;
-	GdkPixbuf *pb;
 
-	factory = gtk_icon_factory_new ();
-	path = g_strdup_printf("%s%c%s%c%s",plugin.path,G_DIR_SEPARATOR, "magnatune",G_DIR_SEPARATOR,"magnatune.png");
-	pb = gdk_pixbuf_new_from_file (path ,NULL);
-	set = gtk_icon_set_new_from_pixbuf (pb);
-	gtk_icon_factory_add (factory, "gmpc-magnatune", set);
+	path = g_strdup_printf("%s%c%s",plugin.path,G_DIR_SEPARATOR, "magnatune");
+	gtk_icon_theme_append_search_path(gtk_icon_theme_get_default (),path);
 	g_free(path);
-	g_object_unref(pb);
-	gtk_icon_factory_add_default (factory);                  
+
 	gtk_init_add((GtkFunction )magnatune_logo_add, NULL);
 	/** 
 	 * init the magnatune stuff
@@ -214,7 +207,7 @@ static void magnatune_get_genre_list()
 							PL3_CAT_TYPE, plugin.id,
 							PL3_CAT_TITLE, (gchar *)node->data, 
 							PL3_CAT_INT_ID, (gchar *)node->data,
-							PL3_CAT_ICON_ID, "gmpc-magnatune",
+							PL3_CAT_ICON_ID, "magnatune",
 							PL3_CAT_PROC, TRUE,
 							PL3_CAT_ICON_SIZE,GTK_ICON_SIZE_MENU,-1);
 					list2 = magnatune_db_get_artist_list(node->data);
@@ -266,19 +259,17 @@ static void magnatune_cover_art_fetched(mpd_Song *song, MetaDataResult ret, char
 				else if(ret == META_DATA_FETCHING)
 				{
 					int size = cfg_get_single_value_as_int_with_default(config, "cover-art", "browser-size",64);
-					GdkPixbuf *pb2, *pb= gtk_widget_render_icon(GTK_WIDGET(magnatune_vbox), "media-loading-cover",-1, NULL);
-					pb2 = gdk_pixbuf_scale_simple(pb,size, size,GDK_INTERP_BILINEAR);
+					GdkPixbuf *pb2;
+					pb2 = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "gmpc-loading-cover", size, 0,NULL);
 					gtk_list_store_set(GTK_LIST_STORE(model),&iter, MAGNA_FIELD_PIXBUF, pb2, -1);
-					if(pb)g_object_unref(pb);
 					if(pb2)g_object_unref(pb2);
 				}
 				else
 				{
 					int size = cfg_get_single_value_as_int_with_default(config, "cover-art", "browser-size",64);
-					GdkPixbuf *pb2,*pb = gtk_widget_render_icon(GTK_WIDGET(magnatune_vbox),"media-no-cover", -1, NULL);
-					pb2 = gdk_pixbuf_scale_simple(pb,size, size,GDK_INTERP_BILINEAR);
+					GdkPixbuf *pb2;
+					pb2 = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "gmpc-no-cover", size, 0,NULL);
 					gtk_list_store_set(GTK_LIST_STORE(model),&iter,MAGNA_FIELD_PIXBUF, pb2, -1);
-					if(pb)g_object_unref(pb);
 					if(pb2)g_object_unref(pb2);
 					gtk_tree_row_reference_free(ref);
 				}
@@ -344,7 +335,7 @@ static void magnatune_show_album_list()
 	if(depth > 1)
 	{
 		GtkTreeIter iter;
-		GdkPixbuf *pb =  gtk_widget_render_icon(magnatune_vbox, "gtk-go-up",GTK_ICON_SIZE_MENU,NULL);
+		GdkPixbuf *pb =  gtk_widget_render_icon(magnatune_vbox, GTK_STOCK_GO_UP,GTK_ICON_SIZE_MENU,NULL);
 
 		gtk_list_store_append(mt_store, &iter);
 		gtk_list_store_set(mt_store, &iter, 
@@ -673,9 +664,11 @@ static void magnatune_download_xml_callback(int download, int total,gpointer dat
 
 static void magnatune_download()
 {
+	gtk_widget_set_sensitive(glade_xml_get_widget(pl3_xml, "pl3_win"), FALSE);
 	gtk_widget_show(magnatune_pb);
 	magnatune_db_download_xml(magnatune_download_xml_callback, magnatune_pb);
 	gtk_widget_hide(magnatune_pb);
+	gtk_widget_set_sensitive(glade_xml_get_widget(pl3_xml, "pl3_win"), TRUE);
 }
 
 void magnatune_add(GtkWidget *cat_tree)
@@ -691,7 +684,7 @@ void magnatune_add(GtkWidget *cat_tree)
 			PL3_CAT_TYPE, plugin.id,
 			PL3_CAT_TITLE, "Magnatune Browser",
 			PL3_CAT_INT_ID, "",
-			PL3_CAT_ICON_ID, "gmpc-magnatune",
+			PL3_CAT_ICON_ID, "magnatune",
 			PL3_CAT_PROC, TRUE,
 			PL3_CAT_ICON_SIZE,GTK_ICON_SIZE_DND,-1);
 	/**
@@ -1054,12 +1047,10 @@ static void magnatune_cat_key_press(GtkWidget *tree, GdkEventKey *event, int sel
 	if(selected_type != plugin.id) return; 
 	if(event->state&GDK_CONTROL_MASK && event->keyval == GDK_Insert)
 	{
-/*		pl3_file_browser_replace_folder(); */
 		magnatune_cat_menu_replace();
 	}
 	else if(event->keyval == GDK_Insert)
 	{
-/*		pl3_file_browser_add_folder(); */
 		magnatune_cat_menu_add();	
 	}
 
@@ -1069,13 +1060,10 @@ static int magnatune_key_press(GtkWidget *tree, GdkEventKey *event)
 {
 	if(event->state&GDK_CONTROL_MASK && event->keyval == GDK_Insert)
 	{
-	/*	pl3_file_browser_replace_selected(); */
-
 		magnatune_replace_selected(NULL, GTK_TREE_VIEW(tree));
 	}
 	else if(event->keyval == GDK_Insert)
 	{
-/*		pl3_file_browser_add_selected(); */
 		magnatune_add_selected(NULL, GTK_TREE_VIEW(tree));
 	}
 	else if (event->keyval == GDK_f && event->state&GDK_CONTROL_MASK)
